@@ -9,6 +9,7 @@ from pytconf import register_endpoint, register_main, config_arg_parse_and_launc
 from pydmt.configs import ConfigSudo, ConfigFlow, ConfigOutput
 from pydmt.core.pydmt import PyDMT
 from pydmt.static import APP_NAME, VERSION_STR, DESCRIPTION
+from pydmt.utils.subprocess import check_call
 
 from pydmt.features.sphinx import FeatureSphinx
 from pydmt.features.mako import FeatureMako
@@ -18,6 +19,21 @@ from pydmt.features.npm import FeatureNpm
 from pydmt.features.venv import FeatureVenv
 
 
+def add_all_features(p):
+    f = FeatureVenv()
+    f.setup(p)
+    f = FeatureMako()
+    f.setup(p)
+    f = FeatureApt()
+    f.setup(p)
+    f = FeatureNpm()
+    f.setup(p)
+    f = FeatureSphinx()
+    f.setup(p)
+    f = FeatureYaml()
+    f.setup(p)
+
+
 def add_to_path():
     """
     This adds to PYTHONPATH various paths we need
@@ -53,18 +69,7 @@ def build():
     pylogconf.core.setup()
     p = PyDMT()
 
-    f = FeatureVenv()
-    f.setup(p)
-    f = FeatureMako()
-    f.setup(p)
-    f = FeatureApt()
-    f.setup(p)
-    f = FeatureNpm()
-    f.setup(p)
-    f = FeatureSphinx()
-    f.setup(p)
-    f = FeatureYaml()
-    f.setup(p)
+    add_all_features(p)
 
     stats = p.build_all()
     sys.exit(stats.get_os_error_code())
@@ -120,7 +125,15 @@ def build_tools():
     description="Clean all generated files"
 )
 def clean() -> None:
-    print("TBD")
+    add_to_path()
+
+    pylogconf.core.setup()
+    p = PyDMT()
+
+    add_all_features(p)
+
+    shutil.rmtree(".pydmt")
+    p.clean_all()
 
 
 @register_endpoint(
@@ -128,6 +141,7 @@ def clean() -> None:
 )
 def clean_hard() -> None:
     shutil.rmtree(".pydmt")
+    check_call(["git", "clean", "-qffxd"])
 
 
 @register_main(
